@@ -1,5 +1,5 @@
 #
-# $Id: Encode.pm,v 2.90 2017/06/10 17:23:50 dankogai Exp dankogai $
+# $Id: Encode.pm,v 2.91 2017/06/22 08:11:05 dankogai Exp dankogai $
 #
 package Encode;
 use strict;
@@ -7,7 +7,7 @@ use warnings;
 use constant DEBUG => !!$ENV{PERL_ENCODE_DEBUG};
 our $VERSION;
 BEGIN {
-    $VERSION = sprintf "%d.%02d", q$Revision: 2.90 $ =~ /(\d+)/g;
+    $VERSION = sprintf "%d.%02d", q$Revision: 2.91 $ =~ /(\d+)/g;
     require XSLoader;
     XSLoader::load( __PACKAGE__, $VERSION );
 }
@@ -342,9 +342,12 @@ if ($ON_EBCDIC) {
 
 {
     package Encode::utf8;
+    BEGIN {
+        $Encode::Encoding{utf8} = bless { Name => 'utf8' } => __PACKAGE__;
+    }
     use parent 'Encode::Encoding';
-    __PACKAGE__->Define('utf8');
-    my $strict_obj = bless { Name => "utf-8-strict", strict_utf8 => 1 } => "Encode::utf8";
+    my $strict_obj =
+      bless { Name => 'utf-8-strict', strict_utf8 => 1 } => __PACKAGE__;
     Encode::define_encoding($strict_obj, 'utf-8-strict');
     sub cat_decode {
         # ($obj, $dst, $src, $pos, $trm, $chk)
